# Changelog
All notable changes to this project will be documented in this file. See [conventional commits](https://www.conventionalcommits.org/) for commit guidelines.

- - -
## v0.0.4 - 2025-01-05
#### Documentation
- add a quick exemple - (c5a856f) - Angel Dijoux

- - -

## v0.0.3 - 2025-01-05
#### Bug Fixes
- job acf fragment & remove testpypi in ci - (6d7082c) - Angel Dijoux

- - -

## v0.0.2 - 2025-01-05
#### Bug Fixes
- **(ci)** package name - (7142481) - Angel Dijoux
#### Miscellaneous Chores
- add fields in job frag & edit next event where param - (3c6a16d) - Angel Dijoux

- - -

## v0.0.1 - 2025-01-02
#### Continuous Integration
- based more on pipy gh action exemple? - (2ad57c1) - Angel Dijoux
- allow manual trigger - (f2d2def) - Angel Dijoux
- following pypi rules for building - (d7c9d5f) - Angel Dijoux
- env is back? - (ff8fcff) - Angel Dijoux
- without pipy env - (5e83fe9) - Angel Dijoux
- simplify env - (2af3931) - Angel Dijoux
- change project name - (a5f7499) - Angel Dijoux
#### Documentation
- remove changelog - (be5e1e1) - Angel Dijoux
#### Features
- initial commit - (00b2893) - Angel Dijoux
#### Miscellaneous Chores
- **(version)** v0.0.4 - (f5b7c2e) - Angel Dijoux
- **(version)** v0.0.3 - (a9b2a94) - Angel Dijoux
- **(version)** v0.0.2 - (07afa88) - Angel Dijoux
- **(version)** v0.0.1 - (4ea06bc) - Angel Dijoux
- reset tag - (96cb81e) - Angel Dijoux
- change sed command - (c0b339a) - Angel Dijoux
- change default first project version - (79ee451) - Angel Dijoux

- - -

Changelog generated by [cocogitto](https://github.com/cocogitto/cocogitto).